@@ -4,13 +4,12 @@
 //! Module containing workers required to create and maintain the ledger state.
 
 pub mod consensus;
+pub mod error;
 pub mod event;
 pub mod pruning;
 pub mod snapshot;
 pub mod storage;
 
-pub(crate) mod error;
-
 pub use storage::StorageBackend;
 
 use consensus::ConsensusWorker;
