@@ -11,12 +11,15 @@ use crate::{
     workers::{
         consensus::worker::migration_from_milestone,
         error::Error,
-        snapshot::{config::SnapshotConfig, download::download_snapshot_file, error::Error as SnapshotError},
+        snapshot::{config::SnapshotConfig, download::download_latest_snapshot_files, error::Error as SnapshotError},
         storage::{self, apply_balance_diffs, apply_milestone, create_output, rollback_milestone, StorageBackend},
     },
 };
 
-use bee_common::packable::{Packable, Read};
+use bee_common::{
+    packable::{Packable, Read},
+    time,
+};
 use bee_message::{
     milestone::MilestoneIndex,
     output::{self, Output, OutputId},
@@ -26,8 +29,7 @@ use bee_message::{
 use bee_storage::access::{Insert, Truncate};
 use bee_tangle::solid_entry_point::SolidEntryPoint;
 
-use chrono::{offset::TimeZone, Utc};
-use log::{info, warn};
+use log::info;
 
 use std::{
     collections::HashMap,
@@ -201,7 +203,7 @@ async fn import_full_snapshot<B: StorageBackend>(storage: &B, path: &Path, netwo
 
     info!(
         "Imported full snapshot file from {} with sep index {}, ledger index {}, {} solid entry points, {} outputs and {} milestone diffs.",
-        Utc.timestamp(header.timestamp() as i64, 0).format("%d-%m-%Y %H:%M:%S"),
+        time::format_unix_timestamp(header.timestamp() as i64),
         *header.sep_index(),
         *header.ledger_index(),
         full_header.sep_count(),
@@ -256,7 +258,7 @@ async fn import_delta_snapshot<B: StorageBackend>(storage: &B, path: &Path, netw
 
     info!(
         "Imported delta snapshot file from {} with sep index {}, ledger index {}, {} solid entry points and {} milestone diffs.",
-        Utc.timestamp(header.timestamp() as i64, 0).format("%d-%m-%Y %H:%M:%S"),
+        time::format_unix_timestamp(header.timestamp() as i64),
         *header.sep_index(),
         *header.ledger_index(),
         delta_header.sep_count(),
@@ -276,25 +278,19 @@ pub(crate) async fn import_snapshots<B: StorageBackend>(
 
     if !full_exists && delta_exists {
         return Err(Error::Snapshot(SnapshotError::OnlyDeltaSnapshotFileExists));
+    } else if !full_exists && !delta_exists {
+        download_latest_snapshot_files(
+            network_id,
+            config.full_path(),
+            config.delta_path(),
+            config.download_urls(),
+        )
+        .await?;
     }
 
-    if !full_exists {
-        download_snapshot_file(config.full_path(), config.download_urls()).await?;
-    }
-
-    // Full snapshot file exists from now on.
-
     import_full_snapshot(storage, config.full_path(), network_id).await?;
 
     if let Some(delta_path) = config.delta_path() {
-        if !delta_exists
-            && download_snapshot_file(delta_path, config.download_urls())
-                .await
-                .is_err()
-        {
-            warn!("Could not download the delta snapshot file and it will not be imported.");
-        }
-
         if delta_path.exists() {
             import_delta_snapshot(storage, delta_path, network_id).await?;
         }
